==> haskell-crypto-token-0.0.2-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.0.2
visibility:           public
id:                   crypto-token-0.0.2-EY11DxgbxpH1Xwka9OQL07
key:                  crypto-token-0.0.2-EY11DxgbxpH1Xwka9OQL07
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  f2e0dccbc80ffce39db0954062e635c3
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.0.2-EY11DxgbxpH1Xwka9OQL07
depends:
    array-0.5.4.0 base-4.17.2.1 crypton-0.34-EiCtHDIuEI9JixmuOKi72q
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-token-0.0.2-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.0.2
visibility:           public
id:                   crypto-token-0.0.2-Ej5LyRJtj2CGPQBxIAOCxM
key:                  crypto-token-0.0.2-Ej5LyRJtj2CGPQBxIAOCxM
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  23e211a9bdc295e51edc5de65a2e15f7
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.0.2-Ej5LyRJtj2CGPQBxIAOCxM
depends:
    array-0.5.4.0 base-4.17.2.1 crypton-0.34-KWVDzjFANKo4u9Jr4Sk6bF
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
